@@ -1,12 +1,14 @@
 from __future__ import annotations
 
-# import profile
+import cProfile as profile
+import os
 import sys
+from typing import NoReturn
 
 from slap.core.cli import CliApp, Group
 
 
-def _main() -> None:
+def _main() -> NoReturn:
     from kraken import core
 
     from . import __version__
@@ -34,16 +36,18 @@ def _main() -> None:
     sys.exit(app.run())
 
 
-def _entrypoint() -> None:
-    _main()
-    # prof = profile.Profile()
-    # try:
-    #     prof.runcall(_main)
-    # finally:
-    #     import pstats
-    #     stats = pstats.Stats(prof)
-    #     stats.sort_stats('cumulative')
-    #     stats.print_stats(.1)
+def _entrypoint() -> NoReturn:
+    profile_outfile = os.getenv("KRAKEN_PROFILING")
+    if profile_outfile:
+        with open(profile_outfile, "w"):
+            pass
+        prof = profile.Profile()
+        try:
+            prof.runcall(_main)
+        finally:
+            prof.dump_stats(profile_outfile)
+    else:
+        _main()
 
 
 if __name__ == "__main__":
