@@ -4,10 +4,19 @@ import abc
 import dataclasses
 from pathlib import Path
 
+from kraken.cli.buildenv.environment import get_implied_requirements
+
 from .requirements import RequirementSpec, parse_requirements_from_python_script
 
+DEFAULT_PYTHONPATH = ["build-support"]
+DEFAULT_INTERPRETER_CONSTRAINT = ">=3.7"
+
 
 class ProjectInterface(abc.ABC):
+    @abc.abstractmethod
+    def get_requirements_path(self) -> Path:
+        ...
+
     @abc.abstractmethod
     def get_requirement_spec(self) -> RequirementSpec:
         """Called to read the requirement spec of the project."""
@@ -27,16 +36,16 @@ class DefaultProjectImpl(ProjectInterface):
     Buildscript requirements are looked up in the `.kraken.py` header if prefixed with the string `# ::requirements`.
     Lockfiles are written to a file named `.kraken.lock`."""
 
-    LOCK_FILES = [Path(".kraken.lock")]
+    LOCK_FILE = Path(".kraken.lock")
 
     @dataclasses.dataclass
     class Files:
-        script: Path | None
+        script: Path
         lock: Path
 
-    def __init__(self, project_dir: Path | None = None, implied_requirements: list[str] | None = None) -> None:
+    def __init__(self, project_dir: Path | None = None, kraken_cli_develop: bool = False) -> None:
         self.project_dir = project_dir or Path.cwd()
-        self._implied_requirements = implied_requirements or []
+        self.kraken_cli_develop = kraken_cli_develop
         self._files: DefaultProjectImpl.Files | None = None
 
     def _get_files(self) -> Files:
@@ -56,29 +65,22 @@ class DefaultProjectImpl(ProjectInterface):
         if not script_file:
             raise RuntimeError("no Kraken build script found")
 
-        # Find the lock file.
-        alternative_lock_file: Path | None = None
-        for path in self.LOCK_FILES:
-            lock_file = self.project_dir / path
-            if lock_file.parent.is_dir() and not alternative_lock_file:
-                alternative_lock_file = lock_file
-            if lock_file.exists():
-                break
-        else:
-            assert alternative_lock_file
-            lock_file = alternative_lock_file
-
-        self._files = self.Files(script_file, lock_file)
+        self._files = self.Files(script_file, self.project_dir / self.LOCK_FILE)
         return self._files
 
+    def get_requirements_path(self) -> Path:
+        return self._get_files().script
+
     def get_requirement_spec(self) -> RequirementSpec:
         files = self._get_files()
-        if files.script:
-            with files.script.open() as fp:
-                requirements = parse_requirements_from_python_script(fp)
-        else:
-            assert False, files
-        requirements.add_requirements(self._implied_requirements)
+        with files.script.open() as fp:
+            requirements = parse_requirements_from_python_script(fp)
+        requirements.add_requirements(get_implied_requirements(self.kraken_cli_develop))
+        for path in DEFAULT_PYTHONPATH:
+            if path not in requirements.pythonpath:
+                requirements.pythonpath.append(path)
+        if not requirements.interpreter_constraint:
+            requirements.interpreter_constraint = DEFAULT_INTERPRETER_CONSTRAINT
         return requirements
 
     def get_lock_file(self) -> Path:
